# Advanced Configuration
### On this page
  * [Endpoints](https://help.sap.com/docs/leanix/ea/sap-signavio-advanced-configuration#endpoints)
  * [Editordata Endpoint](https://help.sap.com/docs/leanix/ea/sap-signavio-advanced-configuration#editordata-endpoint)
  * [Process Language Example](https://help.sap.com/docs/leanix/ea/sap-signavio-advanced-configuration#process-language-example)
  * [Model Endpoint](https://help.sap.com/docs/leanix/ea/sap-signavio-advanced-configuration#model-endpoint)
  * [Glossary Endpoint](https://help.sap.com/docs/leanix/ea/sap-signavio-advanced-configuration#glossary-endpoint)
  * [Advanced Tab](https://help.sap.com/docs/leanix/ea/sap-signavio-advanced-configuration#advanced-tab)
  * [Case 1: A SAP Signavio Field to a Static Value](https://help.sap.com/docs/leanix/ea/sap-signavio-advanced-configuration#case-1:-a-sap-signavio-field-to-a-static-value)
  * [Case 2: SAP Signavio Attributes to Fields](https://help.sap.com/docs/leanix/ea/sap-signavio-advanced-configuration#case-2:-sap-signavio-attributes-to-fields)


View all
Previously, we offered an Advanced Configuration tab to configure some edge cases using complex JSON syntax. Now, most of these cases are managed through the UI, so the Advanced Configuration tab has been deprecated. However, we’re keeping this documentation available for customers who may still have legacy configurations in place.
**Caution**
The Advanced configuration of the SAP Signavio integration is only required for certain edge cases and shouldn't normally be required.
This guide is focused on advanced SAP Signavio use cases and technical information.
